@@ -5,12 +5,12 @@
 
 ################################################################################
 # CHANGE LOG
+# 30.09.2013: Fixed bug when exact=FALSE
+# 17.09.2013: Updated example to support new 'getKit' structure.
 # 31.07.2013: Added parameter 'ignoreCase'.
 # 28.05.2013: Fixed bug any(..., na.rm=TRUE)
 # 21.05.2013: Added a second 'by' level and bugs fixed.
 # 20.05.2013: Handle keys with no match.
-# <20.05.2013: Roxygenized.
-# <20.05.2013: First version
 
 #' @title Adds new data columns to a data frame
 #'
@@ -35,11 +35,11 @@
 #' 
 #' @export true
 #' @examples
-#' # Get marker names for Promega PowerPlex ESX 17.
-#' x <- data.frame(Marker = getKit("ESX17")$locus)
-#' # Get offsets for Promega PowerPlex ESX 17.
-#' y <- data.frame(Marker = getKit("ESX17")$locus, Offset = getKit("ESX17")$offset)
-#' # Get other kit information using string name.
+#' # Get marker names and alleles for Promega PowerPlex ESX 17.
+#' x <- getKit("ESX17", what="Allele")
+#' # Get marker names and colors for Promega PowerPlex ESX 17.
+#' y <- getKit("ESX17", what="Color")
+#' # Add color information to allele information.
 #' z <- addData(data=x, newData=y, byCol="Marker")
 #' print(x)
 #' print(y)
@@ -69,14 +69,19 @@ addData <- function(data, newData, byCol, thenByCol=NULL, exact=TRUE,
   }
   
   # Get unique identifiers.
-  keys <- unique(as.character(data[ , byCol]))
+  keysData <- unique(as.character(data[ , byCol]))
   keysNew <- unique(as.character(newData[ , byCol]))
 
+  # Select keys.
+  if(exact){
+    keys <- keysData
+  } else {
+    keys <- keysNew
+  }
+  
   if(debug){
     print("keys")
     print(keys)
-    print("keysNew")
-    print(keysNew)
   }
   
   # Loop through keys.
@@ -87,9 +92,9 @@ addData <- function(data, newData, byCol, thenByCol=NULL, exact=TRUE,
       selectedData <- data[ , byCol] == keys[k]
       selectedNewData <- newData[ , byCol] == keys[k]
     } else {
-      selectedData <- grepl(keysNew[k], data[ , byCol],
+      selectedData <- grepl(keys[k], data[ , byCol],
                             ignore.case=ignoreCase)
-      selectedNewData <- grepl(keysNew[k], newData[ , byCol],
+      selectedNewData <- grepl(keys[k], newData[ , byCol],
                                ignore.case=ignoreCase)
     }
 
@@ -136,14 +141,19 @@ addData <- function(data, newData, byCol, thenByCol=NULL, exact=TRUE,
       } else {
         
         # Get unique identifiers.
-        keys2 <- unique(as.character(data[ , thenByCol]))
+        keysData2 <- unique(as.character(data[ , thenByCol]))
         keysNew2 <- unique(as.character(newData[ , thenByCol]))
         
+        # Select keys.
+        if(exact){
+          keys2 <- keysData2
+        } else {
+          keys2 <- keysNew2
+        }
+
         if(debug){
           print("keys2")
           print(keys2)
-          print("keysNew2")
-          print(keysNew2)
         }
 
         # Loop through keys.
@@ -154,9 +164,9 @@ addData <- function(data, newData, byCol, thenByCol=NULL, exact=TRUE,
             selectedData2 <- data[ , thenByCol] == keys2[k2] & selectedData
             selectedNewData2 <- newData[ , thenByCol] == keys2[k2] & selectedNewData
           } else {
-            selectedData2 <- grepl(keysNew2[k2], data [ , thenByCol],
+            selectedData2 <- grepl(keys2[k2], data [ , thenByCol],
                                    ignore.case=ignoreCase) & selectedData
-            selectedNewData2 <- grepl(keysNew2[k2], newData[ , thenByCol],
+            selectedNewData2 <- grepl(keys2[k2], newData[ , thenByCol],
                                       ignore.case=ignoreCase) & selectedNewData
           }
           
