@@ -1,9 +1,16 @@
 ################################################################################
 # TODO LIST
+# TODO: optional percentile.
 # TODO: calculate the distributions...
+# TODO: Regression Analysis and construction of Hb bins...
 
 ################################################################################
 # CHANGE LOG
+# 08.01.2014: Filter data and only consider peaks matching reference.
+# 08.01.2014: Fixed bug when two highest peaks are equal.
+# 27.11.2013: Added stop for NA's in 'Dye'.
+# 20.10.2013: Added calculations and column for size difference 'Delta', 'Hb.Min', 'Lb.Min'.
+# 09.09.2013: Added parameter 'hb' to specify the definition of Hb.
 # 26.07.2013: Removed parameters 'minHeight', 'maxHeight', 'matchSource' and related code.
 # 04.06.2013: Added warning/stop for missing markers.
 # 20.04.2013: Lb can be calculated per dye channel with no missing markers.
@@ -12,12 +19,6 @@
 # 20.04.2013: Fixed bug for homozygous: min/2 to max/2.
 # 14.04.2013: Reworked the code:
 #             Removed dependency of column 'Zygosity' by adding parameter 'ref'.
-# <14.04.2013: Roxygenized. Name changed from 'balanceSlim' to 'calculateBalance'.
-# <14.04.2013: new option option 'calculateNA'
-# <14.04.2013: Changed min/max to include given values.
-# <14.04.2013: Calculates MpH for homozygotes ('balanceSlim').
-# <14.04.2013: Implemented parameter 'perDye' in 'balanceSlim'. 'balance' deleted.
-# <14.04.2013: 'balanceSlim' is working.
 
 #' @title Calculate balance
 #'
@@ -25,24 +26,29 @@
 #' \code{calculateBalance} calculates the inter and intra locus balance.
 #'
 #' @details
-#' Calculates the inter and intra locus balance for a filtered dataset.
-#' Takes 'slimmed' data for samples and references as input.At the moment
-#' it is better to discard data prior to analysis than to use min/maxHeight.
+#' Calculates the inter and intra locus balance for a dataset.
+#' Only peaks corresponding to reference alleles will be included in analysis
+#' (does not require filtered data).
+#' Also calculates the allele size difference between heterozygous alleles.
+#' Takes 'slimmed' data for samples and references as input.
 #' NB! Requires at least one row for each marker per sample, even if no data.
+#' NB! 'X' and 'Y' will be handled as '1' and '2' respectively.
 #' 
 #' @param data a data frame containing at least
 #'  'Sample.Name', 'Marker', 'Height', 'Allele', and Dye'.
 #' @param perSample logical, default TRUE calculates balance for each sample, 
 #'  FALSE calculates the average across all samples.
 #' @param lb string. 'prop' is defualt and locus balance is calculated proportionally
-#'  in relation to the whole sample. 'norm' locus balance is normalised in relation to 
-#'  the locus with the highest total peakheight.  
+#' 'norm' locus balance is normalised in relation to the locus with the highest total peakheight.
 #' @param perDye logical, default is TRUE and locus balance is calculated within each dye.
-#'  FALSE locus balance is calculated globally.
+#'  FALSE locus balance is calculated globally across all dyes.
+#' @param hb numerical, definition of heterozygous balance. hb=1; HMW/LMW, hb=2; Max1(Ph)/Max2(Ph).
 #' @param ignoreCase logical indicating if sample matching should ignore case.
 #' 
-#' @return data.frame with with columns 'Sample.Name', 'Marker', 'Hb', 'Lb', 'MpH'. 
-#' Or 'Sample.Name','Marker','Hb.n', 'Hb.Mean', 'Hb.Sd', 'Hb.95','Lb.n', 'Lb.Mean', 'Lb.Sd'.
+#' @return data.frame with with columns 'Sample.Name', 'Marker', 'Delta', 'Hb', 'Lb', 'MPH'. 
+#' Or 'Sample.Name', 'Marker', 'Delta.Mean',
+#' 'Hb.n', 'Hb.Min', 'Hb.Mean', 'Hb.Sd', 'Hb.95',
+#' 'Lb.n', 'Lb.Min', 'Lb.Mean', 'Lb.Sd'.
 #' 
 #' @keywords internal
 #' 
@@ -54,19 +60,36 @@
 #' calculateBalance(data=set2, ref=ref2, perSample=FALSE)
 
 calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
-                             ignoreCase=TRUE, debug=FALSE){
+                             hb=1, ignoreCase=TRUE, debug=FALSE){
   
   if(debug){
     print(paste("IN:", match.call()[[1]]))
+    print("Parameters:")
+    print("data")
+    print(str(data))
+    print("ref")
+    print(str(ref))
+    print("perSample")
+    print(perSample)
+    print("lb")
+    print(lb)
+    print("perDye")
+    print(perDye)
+    print("hb")
+    print(hb)
+    print("ignoreCase")
+    print(ignoreCase)
   }
   
   # Check data ----------------------------------------------------------------
   
   if(perDye){
-    # Keep track of dyes.
-      if(is.null(data$Dye)){
+    if(is.null(data$Dye)){
       stop("'Dye' does not exist!")
     }
+    if(any(is.na(data$Dye))){
+      stop("'Dye' contain NA!")
+    }
   }
   
   if(is.null(data$Sample.Name)){
@@ -130,15 +153,15 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
 
   # Check data type of Height.
   if(typeof(data$Height)!="integer" & typeof(data$Height)!="double" ){
-    warning("'Height' not numeric. Converting to numeric.")
+    message("'Height' not numeric. Converting to numeric.")
     # Convert to numeric.
-    data$Height <- as.numeric(data$Height)
+    data$Height <- suppressWarnings(as.numeric(data$Height))
   }
   
   # Create empty result data frame with NAs.
   res <- data.frame(t(rep(NA,5)))
   # Add column names.
-  names(res) <- c("Sample.Name","Marker","Hb","Lb","MpH")
+  names(res) <- c("Sample.Name","Marker","Hb","Lb","MPH")
   # Remove all NAs
   res <- res[-1,]
   
@@ -172,6 +195,7 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
       # Initialise variables.
       markerPeakHeightSum <- vector()
       markerDye <- vector()
+      delta <- vector()
       hetBalance <- vector()
       mph <- vector()
       locusBalance <- vector()
@@ -189,17 +213,15 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
         markerRows <- cData$Marker == markerNames[m]
         markerRowsRef <- cRef$Marker == markerNames[m]
         
-        markerPeakHeightSum[m] <- sum(cData$Height[markerRows], na.rm=TRUE)
-        
         if(perDye){
           # Keep track of dyes.
           markerDye[m] <- unique(cData$Dye[markerRows])
         }
         
-        # Count number of height values.
-        nbOfPeaks <- sum(!is.na(cData$Height[markerRows]))
+        # Get reference alleles.
         expPeaks <- sum(!is.na(unique(cRef$Allele[markerRowsRef])))
-        
+        expAlleles <- unique(cRef$Allele[markerRowsRef])
+
         if(expPeaks != 1 && expPeaks != 2){
         
           msg <- paste("Expected peaks is not 1 or 2 in reference",
@@ -219,28 +241,112 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
         # Get heights.
         cHeights <- cData$Height[markerRows]
 
+        # Get alleles.
+        cAlleles <- cData$Allele[markerRows]
+
+        # Filter against reference alleles.
+        matchIndex <- cAlleles %in% expAlleles
+        cAlleles <- cAlleles[matchIndex]
+        cHeights <- cHeights[matchIndex]
+
+        if(length(cAlleles) > 2){
+          stop("More than two alleles after matching with reference sample!")
+        }
+        if(length(cHeights) > 2){
+          stop("More than two heigths after matching with reference sample!")
+        }
+        
+        # Sum peaks in current marker (NB! remember to filter first).
+        markerPeakHeightSum[m] <- sum(cHeights)
+        
+        # Handle amelogenin.
+        cAlleles <- gsub("X", "1", cAlleles, fixed=TRUE)
+        cAlleles <- gsub("Y", "2", cAlleles, fixed=TRUE)
+
         # Get min and max peak height.
         if(!all(is.na(cHeights))){
-          max1 <- max(cHeights, na.rm=TRUE)
-          remainingPeaks <- cHeights[cHeights!=max1]
-          if(!all(is.na(remainingPeaks))){
-            max2 <- max(cHeights[cHeights!=max1], na.rm=TRUE)
+          
+          # Get highest peak height (first match in case equal height).
+          indexMax1 <- which(cHeights == max(cHeights, na.rm=TRUE))[1]
+          max1 <- cHeights[indexMax1]
+          
+          # Check if additional peak.
+          if(length(cHeights[-indexMax1]) > 0){
+            
+            # Get second heighest peak height.
+            max2 <- cHeights[-indexMax1]
+            
           } else {
+            
             max2 <- NA
+            
           }
+          
+          # Get allele for highest peak.
+          allele1 <- cAlleles[indexMax1]
+          
+          if(!is.na(max2)){
+            
+            # Get allele for second highest peak.
+            allele2 <- cAlleles[-indexMax1]
+            
+          } else {
+            
+            allele2 <- NA
+            
+          }
+
         } else {
+          
           max2 <- NA
           max1 <- NA
-        }
-
-        # Calculate Hb for two peak loci.
-        if(expPeaks == 2){
-            
-          # Heterozygote balance.
-          hetBalance[m] <- max2 / max1
+          allele1 <- NA
+          allele2 <- NA
           
+        }
+        
+        # Calculate Hb for two peak loci.
+        nominator <- NA
+        denominator <- NA
+        if(expPeaks == 2){
+          
+          if(hb == 1){
+          # High molecular weight over low molecular weigt.
+            
+            if(!is.na(allele1) && !is.na(allele2)){
+
+              if(as.numeric(allele1) > as.numeric(allele2)){
+                nominator <- max1
+                denominator <- max2
+              } else {
+                nominator <- max2
+                denominator <- max1
+              }
+              
+            }
+            
+          } else if(hb == 2){
+          # Highest peak over second highest peak.
+            
+            nominator <- max2
+            denominator <- max1
+            
+          } else {
+          # Not supported.
+            
+            nominator <- NA
+            denominator <- NA
+            
+          }
+          
+          # Heterozygote balance.
+          hetBalance[m] <- nominator / denominator
+
           # Mean peak height.
-          mph[m] <-  sum(max2,max1) / 2
+          mph[m] <-  sum(nominator, denominator) / 2
+          
+          # Difference in size between the alleles.
+          delta[m] <- abs(as.numeric(allele1) - as.numeric(allele2))
           
         } else if(expPeaks == 1){
           
@@ -250,9 +356,13 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
           # Mean peak height.
           mph[m] <-  max1 / 2
           
+          # Difference in size between the alleles.
+          delta[m] <- NA
+            
         } else {
           hetBalance[m] <- NA
           mph[m] <-  NA
+          delta[m] <- NA
         }
 
       }
@@ -273,6 +383,16 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
         allMarkersOk <- FALSE
       }
 
+      if(debug){
+        print("dyes")
+        print(dyes)
+        print("markerPeakHeightSum")
+        print(markerPeakHeightSum)
+        print("dyeOk")
+        print(dyeOk)
+      }
+      
+      
       # Calculate inter locus balance.
       if(lb=="norm"){
         if(perDye & any(dyeOk)){
@@ -331,9 +451,10 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
       # Save result in temporary data frame.
       tmp <- data.frame(Sample.Name = cSample,
                         Marker = markerNames,
+                        Delta = delta,
                         Hb = hetBalance,
                         Lb = locusBalance,
-                        MpH = mph)
+                        MPH = mph)
       
       # Add result to data frame.
       res <- rbind(res, tmp)
@@ -345,9 +466,12 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
   if(perSample==FALSE) {
     
     lbN <- vector()
+    lbMin <- vector()
     lbMean <- vector()
     lbSd <- vector()
     hbN <- vector()
+    deltaMean <- vector()
+    hbMin <- vector()
     hbMean <- vector()
     hbSd <- vector()
     hb95 <- vector()
@@ -361,11 +485,15 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
       # Get marker name.
       cMarkerName <- markerNames[m]
       
-      # Sum Lb per marker over all samples.
+      # Calculate means, n, and standard deviations.
+      lbMin[m] <- suppressWarnings(min(res$Lb[res$Marker==cMarkerName], na.rm=TRUE))
       lbMean[m] <- mean(res$Lb[res$Marker==cMarkerName], na.rm=TRUE)
       lbSd[m] <- sd(res$Lb[res$Marker==cMarkerName], na.rm=TRUE)
       lbN[m] <- sum(!is.na(res$Lb[res$Marker==cMarkerName]))
       
+      deltaMean[m] <- mean(res$Delta[res$Marker==cMarkerName], na.rm=TRUE)
+      
+      hbMin[m] <- suppressWarnings(min(res$Hb[res$Marker==cMarkerName], na.rm=TRUE))
       hbMean[m] <- mean(res$Hb[res$Marker==cMarkerName], na.rm=TRUE)
       hbSd[m] <- sd(res$Hb[res$Marker==cMarkerName], na.rm=TRUE)
       hbN[m] <- sum(!is.na(res$Hb[res$Marker==cMarkerName]))
@@ -374,11 +502,11 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
     }
     
     # Create empty result data frame with NAs.
-    resPerSample <- data.frame(t(rep(NA,10)))
+    resPerSample <- data.frame(t(rep(NA,13)))
     # Add column names.
     names(resPerSample) <- c("Sample.Name","Marker",
-                             "Hb.n", "Hb.Mean", "Hb.Sd", "Hb.95",
-                             "Lb.n", "Lb.Mean", "Lb.Sd")
+                             "Hb.n", "Delta.Min", "Hb.Min", "Hb.Mean", "Hb.Sd", "Hb.95",
+                             "Lb.n", "Lb.Min", "Lb.Mean", "Lb.Sd")
     # Remove all NAs
     res <- res[-1,]
     
@@ -386,12 +514,16 @@ calculateBalance <- function(data, ref, perSample=TRUE, lb="prop", perDye=TRUE,
     resPerSample <- data.frame(Sample.Name = "Total",
                                Marker = markerNames,
                                Hb.n = hbN,
+                               Delta.Mean = deltaMean,
+                               Hb.Min = hbMin,
                                Hb.Mean = hbMean,
                                Hb.Sd = hbSd,
                                Hb.95 = hb95,
                                Lb.n = lbN,
+                               Lb.Min = lbMin,
                                Lb.Mean = lbMean,
-                               Lb.Sd = lbSd)
+                               Lb.Sd = lbSd,
+                               stringsAsFactors = FALSE)
     
     if(debug){
       print(paste("EXIT:", match.call()[[1]]))
