@@ -34,11 +34,6 @@
 
 calculateH_gui <- function(env=parent.frame(), debug=FALSE){
   
-  
-  # Load dependencies.  
-  require(gWidgets)
-  options(guiToolkit="RGtk2")
-  
   # Global variables.
   .gData <- NULL
   
