@@ -4,6 +4,10 @@
 
 ################################################################################
 # CHANGE LOG
+# 30.11.2013: Fixed info when factors.
+# 27.09.2013: Added option to specify data type and warning for dropout dataset.
+# 26.09.2013: Fixed NA rows in resulting data frame.
+# 16.09.2013: Changed 'edit' to 'combobox' populated with unique values.
 # 06.08.2013: Added exclude NA.
 # 01.08.2013: GUI 'info' updates and bug fixes.
 # 18.07.2013: Check before overwrite object.
@@ -23,10 +27,6 @@
 
 cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
-  # Load dependencies.  
-  require(gWidgets)
-  options(guiToolkit="RGtk2")
-  
   # Global variables.
   .gData <- NULL
   .gDataName <- NULL
@@ -82,6 +82,16 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       
       .gDataName <<- val_obj
       
+      # Check for dropout dataset and warn.
+      if("Dropout" %in% names(.gData)){
+        message <- paste("Do not make subsets of a drop-out dataset before modelling!",
+                         "1) Make a subset from the original data.",
+                         "2) Run calculate dropout on that subset.",
+                         "3) Model drop-out from the new drop-out dataset.", sep="\n  ")
+        gmessage(message, title="Warning!",
+                 icon = "warning", parent = w) 
+      }
+      
       
       samples <- length(unique(.gData$Sample.Name))
       svalue(g0_samples_lbl) <- paste(" ", samples, "samples,")
@@ -121,22 +131,23 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   } )  
   
   # FRAME 1 ###################################################################
-  
-  f1 <- gframe(text = "Select target",
+
+  f1 <- gframe(text = "Column",
                horizontal=TRUE,
                spacing = 15,
                container = gv) 
   
-  glabel(text="Select column:", container=f1)
+  glabel(text="Select target column:", container=f1)
   
   f1_column_drp <- gdroplist(items="<Select column>", 
                                       selected = 1,
                                       editable = FALSE,
                                       container = f1)
   
-  f1_na_chk <- gcheckbox(text="Exclude NA", checked=FALSE, container=f1)
+  glabel(text=" Info:", container=f1)
   f1_min_lbl <- glabel(text=" Min:", container=f1)
   f1_max_lbl <- glabel(text=" Max:", container=f1)
+  f1_na_chk <- gcheckbox(text="Exclude NA", checked=FALSE, container=f1)
   
   addHandlerChanged(f1_column_drp, handler = function (h, ...) {
     
@@ -150,19 +161,43 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     .refresh_info()
     
   } )  
+
+  addHandlerChanged(f1_column_drp, handler = function (h, ...) {
+      
+    val_column <- svalue(f1_column_drp)
+    
+    # Detect data type.
+    if(!is.null(.gData) & !is.null(val_column)){
+      # Check that a (existing) column is selected.
+      if(val_column %in% names(.gData)){
+        if(is.numeric(.gData[ , val_column])){
+          svalue(f2_type_opt, index=TRUE) <- 1
+        } else if(is.character(.gData[ , val_column])){
+          svalue(f2_type_opt, index=TRUE) <- 2
+        } else {
+          if(debug){
+            print("Selected column is not 'numeric' and not 'character'")
+          }
+        }
+      }
+    }
+  
+  } )  
   
   # FRAME 2 ###################################################################
   
   f2 <- gframe(text = "Options",
                horizontal=FALSE,
-               spacing = 15,
+               spacing = 5,
                container = gv) 
   
   f2_savegui_chk <- gcheckbox(text="Save GUI settings",
                               checked=FALSE,
                               container=f2)
   
-  f2g1 <- glayout(container = f2, spacing = 10)
+  glabel(text="Action:", visible=FALSE, anchor=c(-1, -1), container=f2)
+  
+  f2g1 <- glayout(container = f2, spacing = 5)
   
   f2g1[1,1] <- f2g1_task_opt <- gradio(items=c("Crop/Discard values", "Replace values"), 
                                             selected = 1,
@@ -173,18 +208,23 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                 "equal to", "not equal to",
                 "is NA", "is not NA")
   
-  f2g1[1,3] <- f2g1_operation_drp <- gdroplist(items=f2_items, container=f2g1)
-  
-  f2g1[1,4] <- f2g1_target_edt <- gedit(text="", width=10, container=f2g1)
+  f2g1[1,2] <- f2g1_operator_drp <- gdroplist(items=f2_items, container=f2g1)
 
-  f2g1[1,5] <- f2g1_new_lbl <- glabel(text="with",
+  # Note: <Target> is only to create width of the widget.
+  #       It will be replaced when a target column is selected.
+  f2g1[1,3] <- f2g1_target_cbo <- gcombobox(items="<Target value>",
+                                            selected = 1,
+                                            editable = TRUE,
+                                            container = f2g1)
+  
+  f2g1[1,4] <- f2g1_new_lbl <- glabel(text="with",
                                       visible=FALSE,
-                                      anchor=c(0 ,0),
+                                      anchor=c(0, -1),
                                       container=f2g1)
 
-  f2g1[1,6] <- f2g1_new_edt <- gedit(text="", 
+  f2g1[1,5] <- f2g1_new_edt <- gedit(text="", 
                                      visible=FALSE,
-                                     width=10,
+                                     width=15,
                                      container=f2g1)
   
   addHandlerChanged(f2g1_task_opt, handler = function (h, ...) {
@@ -193,12 +233,21 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
   } )  
   
-  addHandlerChanged(f2g1_operation_drp, handler = function (h, ...) {
+  addHandlerChanged(f2g1_operator_drp, handler = function (h, ...) {
     
     .refresh_options()
     
   } )  
   
+  glabel(text="Target column contain data of type:",
+         visible=FALSE, anchor=c(-1 , -1), container=f2)
+  
+  f2_type_opt <- gradio(items=c("Numeric", "Character"),
+                        horizontal = FALSE,
+                        selected = 1,
+                        container = f2)
+  
+  
   # BUTTON ####################################################################
   
   apply_btn <- gbutton(text="Apply",
@@ -210,19 +259,33 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
     val_column <- svalue(f1_column_drp)
     val_task <- svalue(f2g1_task_opt, index=TRUE)
-    val_operation <- svalue(f2g1_operation_drp, index=TRUE)
-    val_target <- svalue(f2g1_target_edt)
+    val_operator <- svalue(f2g1_operator_drp, index=TRUE)
+    val_target <- svalue(f2g1_target_cbo)
     val_new <- svalue(f2g1_new_edt)
+    val_type <- svalue(f2_type_opt, index=TRUE)
     
     # If second round, get name from save box.
     if(svalue(dataset_drp, index=TRUE) == 1){
       .gDataName <<- svalue(f3_save_edt)      
     }
-    
-    # Convert to numerical values.
-    if(is.numeric(.gData[ , val_column])){
+
+    # Check data type and convert.
+    if(val_type == 1){  # Numeric.
       val_target <- as.numeric(val_target)
       val_new <- as.numeric(val_new)
+      if(!is.numeric(.gData[ , val_column])){
+        .gData[ , val_column] <<- as.numeric(.gData[ , val_column])
+        warning("Target column not numeric. Data converted!")
+      }
+    } else if(val_type == 2){  # Character.
+      val_target <- as.character(val_target) # Not needed, edit box always character.
+      val_new <- as.character(val_new) # Not needed, edit box always character.
+      if(!is.character(.gData[ , val_column])){
+        .gData[ , val_column] <<- as.character(.gData[ , val_column])
+        warning("Target column not character. Data converted!")
+      }
+    } else {
+      warning(paste("Unsupported data type selected!", val_type))
     }
 
     if(debug){
@@ -230,21 +293,35 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       print(val_column)
       print("val_task")
       print(val_task)
-      print("val_operation")
-      print(val_operation)
+      print("val_operator")
+      print(val_operator)
       print("val_target")
       print(val_target)
       print("val_new")
       print(val_new)
+      print("val_type")
+      print(val_type)
     }
     
     # Change button.
     svalue(apply_btn) <- "Processing..."
     enabled(apply_btn) <- FALSE
+    svalue(f3_save_btn) <- "Save"
     
     if(!is.null(.gData) && !is.null(.gData)){
+
+      if(debug){
+        print(".gData dim, str, head, tail:")
+        print(dim(.gData))
+        print(str(.gData))
+        print(head(.gData))
+        print(tail(.gData))
+      }
       
-      if(val_operation == 1){  # above
+      if(val_operator == 1){  # above
+        
+        # Remove all rows with NA in target column.
+        .gData <<- .gData[!is.na(.gData[val_column]), ]
         
         if(val_task == 1){  # crop
           .gData <<- .gData[!.gData[val_column] > val_target, ]
@@ -252,7 +329,10 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
           .gData[val_column][.gData[val_column] > val_target] <<- val_new
         }
         
-      } else if (val_operation == 2){  # above or equal to
+      } else if (val_operator == 2){  # above or equal to
+
+        # Remove all rows with NA in target column.
+        .gData <<- .gData[!is.na(.gData[val_column]), ]
 
         if(val_task == 1){  # crop
           .gData <<- .gData[!.gData[val_column] >= val_target, ]
@@ -260,15 +340,29 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
           .gData[val_column][.gData[val_column] >= val_target] <<- val_new
         }
         
-      } else if (val_operation == 3){  # below
+      } else if (val_operator == 3){  # below
       
+        # Remove all rows with NA in target column.
+        .gData <<- .gData[!is.na(.gData[val_column]), ]
+
+        if(debug){
+          print(".gData dim, str, head, tail:")
+          print(dim(.gData))
+          print(str(.gData))
+          print(head(.gData))
+          print(tail(.gData))
+        }
+        
         if(val_task == 1){  # crop
           .gData <<- .gData[!.gData[val_column] < val_target, ]
         } else {  # replace
           .gData[val_column][.gData[val_column] < val_target] <<- val_new
         }
       
-      } else if (val_operation == 4){  # below or equal to
+      } else if (val_operator == 4){  # below or equal to
+        
+        # Remove all rows with NA in target column.
+        .gData <<- .gData[!is.na(.gData[val_column]), ]
         
         if(val_task == 1){  # crop
           .gData <<- .gData[!.gData[val_column] <= val_target, ]
@@ -276,23 +370,29 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
           .gData[val_column][.gData[val_column] <= val_target] <<- val_new
         }
         
-      } else if (val_operation == 5){  # equal to
+      } else if (val_operator == 5){  # equal to
         
+        # Remove all rows with NA in target column.
+        .gData <<- .gData[!is.na(.gData[val_column]), ]
+
         if(val_task == 1){  # crop
           .gData <<- .gData[!.gData[val_column] == val_target, ]
         } else {  # replace
           .gData[val_column][.gData[val_column] == val_target] <<- val_new
         }
         
-      } else if (val_operation == 6){  # not equal to
+      } else if (val_operator == 6){  # not equal to
         
+        # Remove all rows with NA in target column.
+        .gData <<- .gData[!is.na(.gData[val_column]), ]
+
         if(val_task == 1){  # crop
           .gData <<- .gData[!.gData[val_column] != val_target, ]
         } else {  # replace
           .gData[val_column][.gData[val_column] != val_target] <<- val_new
         }
         
-      } else if (val_operation == 7){  # is NA
+      } else if (val_operator == 7){  # is NA
         
         if(val_task == 1){  # crop
           .gData <<- .gData[!is.na(.gData[val_column]), ]
@@ -300,7 +400,7 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
           .gData[val_column][is.na(.gData[val_column])] <<- val_new
         }
         
-      } else if (val_operation == 8){  # is not NA
+      } else if (val_operator == 8){  # is not NA
         
         if(val_task == 1){  # crop
           .gData <<- .gData[is.na(.gData[val_column]), ]
@@ -310,6 +410,14 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         
       }
       
+      if(debug){
+        print(".gData dim, str, head, tail:")
+        print(dim(.gData))
+        print(str(.gData))
+        print(head(.gData))
+        print(tail(.gData))
+      }
+      
     } else {
       
       gmessage(message="Data frame is NULL or NA!",
@@ -359,12 +467,17 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
     if(debug){
       print("Save pressed!")
-      print(head(.gData))
       print(val_name)
+      print(".gData dim, str, head, tail:")
+      print(dim(.gData))
+      print(str(.gData))
+      print(head(.gData))
+      print(tail(.gData))
     }
     
     # Save data.
     saveObject(name=val_name, object=datanew, parent=w, env=env)
+    svalue(f3_save_btn) <- "Saved!"
     
   } )
   
@@ -372,6 +485,10 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   .refresh_column_drp <- function(){
     
+    if(debug){
+      print("Refresh column dropdown")
+    }
+    
     # Get data frames in global workspace.
     dfs <- names(.gData)
 
@@ -385,19 +502,38 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       unblockHandler(f1_column_drp)
       
     }
+    
+    if(debug){
+      print("Column dropdown refreshed!")
+    }
   }
   
   .refresh_info <- function(){
+
+    if(debug){
+      print("Refresh info")
+    }
     
     val_col <- svalue(f1_column_drp)
     val_na <- svalue(f1_na_chk)
-
+    
     if(length(val_col)!=0){
       if(val_col %in% names(.gData)){
         
         # Update info:
-        svalue(f1_min_lbl) <- paste(" Min:", min(.gData[,val_col], na.rm=val_na))
-        svalue(f1_max_lbl) <- paste(" Max:", max(.gData[,val_col], na.rm=val_na))
+        if(is.factor(.gData[,val_col])){
+          svalue(f1_min_lbl) <- paste(" Min:",
+                                      min(as.character(.gData[,val_col]),
+                                                   na.rm=val_na))
+          svalue(f1_max_lbl) <- paste(" Max:",
+                                      max(as.character(.gData[,val_col]),
+                                                   na.rm=val_na))
+        } else {
+          svalue(f1_min_lbl) <- paste(" Min:",
+                                      min(.gData[,val_col], na.rm=val_na))
+          svalue(f1_max_lbl) <- paste(" Max:", 
+                                      max(.gData[,val_col], na.rm=val_na))
+        }
         
         # Update 'Save As'
         samples <- length(unique(.gData$Sample.Name))
@@ -417,12 +553,30 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       }
     }
 
+    if(debug){
+      print("Info refreshed!")
+    }
+    
   }
 
   .refresh_options <- function(){
     
+    if(debug){
+      print("Refresh options")
+    }
+    
     val_col <- svalue(f2g1_task_opt, index=TRUE)
-    val_drp <- svalue(f2g1_operation_drp, index=TRUE)
+    val_drp <- svalue(f2g1_operator_drp, index=TRUE)
+    
+    # Update target combo with column content.
+    if(!is.null(.gData)){
+      selectedColumn <- svalue(f1_column_drp)
+      if(length(selectedColumn)!=0){
+        if(selectedColumn %in% names(.gData)){
+          f2g1_target_cbo[,] <- unique(.gData[selectedColumn])
+        }
+      }
+    }
         
     # Crop.
     if(val_col == 1){
@@ -432,11 +586,11 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       
       # NA
       if(val_drp == 7 || val_drp == 8){
-        svalue(f2g1_target_edt) <- NA
-        enabled(f2g1_target_edt) <- FALSE
+        svalue(f2g1_target_cbo) <- NA
+        enabled(f2g1_target_cbo) <- FALSE
         svalue(f2g1_new_edt) <- NA
       } else {
-        enabled(f2g1_target_edt) <- TRUE
+        enabled(f2g1_target_cbo) <- TRUE
       }
       
     } else {
@@ -446,14 +600,18 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         
       # NA
       if(val_drp == 7 || val_drp == 8){
-        svalue(f2g1_target_edt) <- NA
-        enabled(f2g1_target_edt) <- FALSE
+        svalue(f2g1_target_cbo) <- NA
+        enabled(f2g1_target_cbo) <- FALSE
         svalue(f2g1_new_edt) <- NA
       } else {
-        enabled(f2g1_target_edt) <- TRUE
+        enabled(f2g1_target_cbo) <- TRUE
       }
     }
       
+    if(debug){
+      print("Options refreshed!")
+    }
+    
   }
   
   .loadSavedSettings <- function(){
@@ -467,8 +625,8 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       }  
     } else {
       # Load save flag.
-      if(exists(".cropData_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f2_savegui_chk) <- get(".cropData_gui_savegui", envir=env)
+      if(exists(".strvalidator_cropData_gui_savegui", envir=env, inherits = FALSE)){
+        svalue(f2_savegui_chk) <- get(".strvalidator_cropData_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
@@ -480,20 +638,17 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
     # Then load settings if true.
     if(svalue(f2_savegui_chk)){
-      if(exists(".cropData_gui_na", envir=env, inherits = FALSE)){
-        svalue(f1_na_chk) <- get(".cropData_gui_na", envir=env)
+      if(exists(".strvalidator_cropData_gui_na", envir=env, inherits = FALSE)){
+        svalue(f1_na_chk) <- get(".strvalidator_cropData_gui_na", envir=env)
       }
-      if(exists(".cropData_gui_task", envir=env, inherits = FALSE)){
-        svalue(f2g1_task_opt) <- get(".cropData_gui_task", envir=env)
+      if(exists(".strvalidator_cropData_gui_task", envir=env, inherits = FALSE)){
+        svalue(f2g1_task_opt) <- get(".strvalidator_cropData_gui_task", envir=env)
       }
-      if(exists(".cropData_gui_operation", envir=env, inherits = FALSE)){
-        svalue(f2g1_operation_drp) <- get(".cropData_gui_operation", envir=env)
+      if(exists(".strvalidator_cropData_gui_operator", envir=env, inherits = FALSE)){
+        svalue(f2g1_operator_drp) <- get(".strvalidator_cropData_gui_operator", envir=env)
       }
-      if(exists(".cropData_gui_target", envir=env, inherits = FALSE)){
-        svalue(f2g1_target_edt) <- get(".cropData_gui_target", envir=env)
-      }
-      if(exists(".cropData_gui_new", envir=env, inherits = FALSE)){
-        svalue(f2g1_new_edt) <- get(".cropData_gui_new", envir=env)
+      if(exists(".strvalidator_cropData_gui_new", envir=env, inherits = FALSE)){
+        svalue(f2g1_new_edt) <- get(".strvalidator_cropData_gui_new", envir=env)
       }
       if(debug){
         print("Saved settings loaded!")
@@ -507,32 +662,28 @@ cropData_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     # Then save settings if true.
     if(svalue(f2_savegui_chk)){
       
-      assign(x=".cropData_gui_savegui", value=svalue(f2_savegui_chk), envir=env)
-      assign(x=".cropData_gui_na", value=svalue(f1_na_chk), envir=env)
-      assign(x=".cropData_gui_task", value=svalue(f2g1_task_opt), envir=env)
-      assign(x=".cropData_gui_operation", value=svalue(f2g1_operation_drp), envir=env)
-      assign(x=".cropData_gui_target", value=svalue(f2g1_target_edt), envir=env)
-      assign(x=".cropData_gui_new", value=svalue(f2g1_new_edt), envir=env)
+      assign(x=".strvalidator_cropData_gui_savegui", value=svalue(f2_savegui_chk), envir=env)
+      assign(x=".strvalidator_cropData_gui_na", value=svalue(f1_na_chk), envir=env)
+      assign(x=".strvalidator_cropData_gui_task", value=svalue(f2g1_task_opt), envir=env)
+      assign(x=".strvalidator_cropData_gui_operator", value=svalue(f2g1_operator_drp), envir=env)
+      assign(x=".strvalidator_cropData_gui_new", value=svalue(f2g1_new_edt), envir=env)
       
     } else { # or remove all saved values if false.
       
-      if(exists(".cropData_gui_savegui", envir=env, inherits = FALSE)){
-        remove(".cropData_gui_savegui", envir = env)
+      if(exists(".strvalidator_cropData_gui_savegui", envir=env, inherits = FALSE)){
+        remove(".strvalidator_cropData_gui_savegui", envir = env)
       }
-      if(exists(".cropData_gui_na", envir=env, inherits = FALSE)){
-        remove(".cropData_gui_na", envir = env)
+      if(exists(".strvalidator_cropData_gui_na", envir=env, inherits = FALSE)){
+        remove(".strvalidator_cropData_gui_na", envir = env)
       }
-      if(exists(".cropData_gui_task", envir=env, inherits = FALSE)){
-        remove(".cropData_gui_task", envir = env)
+      if(exists(".strvalidator_cropData_gui_task", envir=env, inherits = FALSE)){
+        remove(".strvalidator_cropData_gui_task", envir = env)
       }
-      if(exists(".cropData_gui_operation", envir=env, inherits = FALSE)){
-        remove(".cropData_gui_operation", envir = env)
+      if(exists(".strvalidator_cropData_gui_operator", envir=env, inherits = FALSE)){
+        remove(".strvalidator_cropData_gui_operator", envir = env)
       }
-      if(exists(".cropData_gui_target", envir=env, inherits = FALSE)){
-        remove(".cropData_gui_target", envir = env)
-      }
-      if(exists(".cropData_gui_new", envir=env, inherits = FALSE)){
-        remove(".cropData_gui_new", envir = env)
+      if(exists(".strvalidator_cropData_gui_new", envir=env, inherits = FALSE)){
+        remove(".strvalidator_cropData_gui_new", envir = env)
       }
       
       if(debug){
