@@ -4,6 +4,10 @@
 
 ################################################################################
 # CHANGE LOG
+# 12.01.2014: Replaced 'subset' with native code.
+# 15.12.2013: Fixed filter by kit bins.
+# 09.12.2013: Added 'filter by' option.
+# 09.12.2013: Added check subset button.
 # 18.07.2013: Check before overwrite object.
 # 15.07.2013: Added save GUI settings.
 # 11.06.2013: Added 'inherits=FALSE' to 'exists'.
@@ -27,10 +31,6 @@
 
 filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
-  # Load dependencies.  
-  require(gWidgets)
-  options(guiToolkit="RGtk2")
-  
   .gData <- NULL
   .gDataName <- NULL
   .gRef <- NULL
@@ -66,7 +66,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   g0[1,1] <- glabel(text="Select dataset:", container=g0)
 
-  g0[1,2] <- dataset_drp <- gdroplist(items=c("<Select dataset>",
+  g0[1,2] <- g0_dataset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
                                                objClass="data.frame")), 
                            selected = 1,
@@ -75,9 +75,9 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   g0[1,3] <- g0_samples_lbl <- glabel(text=" 0 samples", container=g0)
   
-  addHandlerChanged(dataset_drp, handler = function (h, ...) {
+  addHandlerChanged(g0_dataset_drp, handler = function (h, ...) {
     
-    val_obj <- svalue(dataset_drp)
+    val_obj <- svalue(g0_dataset_drp)
     
     if(exists(val_obj, envir=env, inherits = FALSE)){
 
@@ -98,7 +98,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         
         # Reset components.
         .gData <<- NULL
-        svalue(dataset_drp, index=TRUE) <- 1
+        svalue(g0_dataset_drp, index=TRUE) <- 1
         svalue(g0_samples_lbl) <- " 0 samples"
         svalue(f2_save_edt) <- ""
         
@@ -114,7 +114,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         
         # Reset components.
         .gData <<- NULL
-        svalue(dataset_drp, index=TRUE) <- 1
+        svalue(g0_dataset_drp, index=TRUE) <- 1
         svalue(g0_samples_lbl) <- " 0 samples"
         svalue(f2_save_edt) <- ""
         
@@ -126,22 +126,27 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         svalue(g0_samples_lbl) <- paste("", samples, "samples")
         svalue(f2_save_edt) <- paste(.gDataName, "_filter", sep="")
         
+        # Detect kit.
+        kitIndex <- detectKit(.gData)
+        # Select in dropdown.
+        svalue(g0_kit_drp, index=TRUE) <- kitIndex
+        
       }
       
     } else {
       
       # Reset components.
       .gData <<- NULL
-      svalue(dataset_drp, index=TRUE) <- 1
+      svalue(g0_dataset_drp, index=TRUE) <- 1
       svalue(g0_samples_lbl) <- " 0 samples"
       svalue(f2_save_edt) <- ""
       
     }
   } )  
   
-  g0[2,1] <- glabel(text="Select reference dataset:", container=g0)
+  g0[2,1] <- g0_refset_lbl <- glabel(text="Select reference:", container=g0)
   
-  g0[2,2] <- refset_drp <- gdroplist(items=c("<Select dataset>",
+  g0[2,2] <- g0_refset_drp <- gdroplist(items=c("<Select dataset>",
                                    listObjects(env=env,
                                                objClass="data.frame")), 
                            selected = 1,
@@ -150,9 +155,9 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   g0[2,3] <- g0_ref_lbl <- glabel(text=" 0 references", container=g0)
   
-  addHandlerChanged(refset_drp, handler = function (h, ...) {
+  addHandlerChanged(g0_refset_drp, handler = function (h, ...) {
     
-    val_obj <- svalue(refset_drp)
+    val_obj <- svalue(g0_refset_drp)
     
     if(exists(val_obj, envir=env, inherits = FALSE)){
       
@@ -174,7 +179,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
 
         # Reset components.
         .gRef <<- NULL
-        svalue(refset_drp, index=TRUE) <- 1
+        svalue(g0_refset_drp, index=TRUE) <- 1
         svalue(g0_ref_lbl) <- " 0 references"
         
       } else if (!slimmed) {
@@ -189,7 +194,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
         
         # Reset components.
         .gRef <<- NULL
-        svalue(refset_drp, index=TRUE) <- 1
+        svalue(g0_refset_drp, index=TRUE) <- 1
         svalue(g0_ref_lbl) <- " 0 references"
         
       } else {
@@ -204,12 +209,68 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
 
       # Reset components.
       .gRef <<- NULL
-      svalue(refset_drp, index=TRUE) <- 1
+      svalue(g0_refset_drp, index=TRUE) <- 1
       svalue(g0_ref_lbl) <- " 0 references"
       
     }
     
-  } )  
+  } )
+  
+  # CHECK ---------------------------------------------------------------------
+  
+  g0[3,2] <- g0_check_btn <- gbutton(text="Check subsetting",
+                                         border=TRUE,
+                                         container=g0)
+  
+  addHandlerChanged(g0_check_btn, handler = function(h, ...) {
+    
+    # Get values.
+    val_data <- .gData
+    val_ref <- .gRef
+    val_ignore <- svalue(f1_ignore_case_chk)
+    val_word <- FALSE
+    
+    if (!is.null(.gData) || !is.null(.gRef)){
+      
+      chksubset_w <- gwindow(title = "Check subsetting",
+                             visible = FALSE, name=title,
+                             width = NULL, height= NULL, parent=w,
+                             handler = NULL, action = NULL)
+      
+      chksubset_txt <- checkSubset(data=val_data,
+                                   ref=val_ref,
+                                   console=FALSE,
+                                   ignoreCase=val_ignore,
+                                   word=val_word)
+      
+      gtext (text = chksubset_txt, width = NULL, height = 300, font.attr = NULL, 
+             wrap = FALSE, container = chksubset_w)
+      
+      visible(chksubset_w) <- TRUE
+      
+    } else {
+      
+      gmessage(message="Data frame is NULL!\n\n
+               Make sure to select a dataset and a reference set",
+               title="Error",
+               icon = "error")      
+      
+    } 
+    
+  } )
+  
+  # Kit -------------------------------------------------------------------
+  
+  g0[4,1] <- g0_kit_lbl <- glabel(text="Select kit:", container=g0)
+  
+  g0[4,2] <- g0_kit_drp <- gdroplist(items=getKit(),
+                                     selected = 1,
+                                     editable = FALSE,
+                                     container = g0) 
+  
+  g0[4,3] <- g0_kit_chk <- gcheckbox(text="Exclude virtual bins.",
+                                         checked=TRUE,
+                                         container=g0)
 
   # FRAME 1 ###################################################################
   
@@ -226,13 +287,28 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
                                     checked = TRUE,
                                     container = f1)
   
-  f1_keep_na_chk <- gcheckbox(text="Keep NA",
-                           checked = FALSE,
-                           container = f1)
-  
-  f1_ignore_case_chk <- gcheckbox(text="Ignore case",
+  f1_keep_na_chk <- gcheckbox(text="Keep loci/sample even if no matching allele",
                            checked = TRUE,
                            container = f1)
+  
+  f1_ignore_case_chk <- gcheckbox(text="Ignore case ",
+                           checked = TRUE,
+                           container = f1)
+  
+  f1_options <- c("Filter by reference dataset",
+                  "Filter by kit bins (allelic ladder)")
+  
+  f1_filter_opt <- gradio(items=f1_options,
+                          selected=1,
+                          horizontal=FALSE,
+                          container=f1)
+  
+  addHandlerChanged(f1_filter_opt, handler = function (h, ...) {
+    
+    .refreshOptions()
+    
+  } )  
+  
 
   # FRAME 2 ###################################################################
   
@@ -254,19 +330,37 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   addHandlerChanged(filter_btn, handler = function(h, ...) {
     
+    val_data <- .gData
+    val_ref <- .gRef
     val_add_missing_loci <- svalue(f1_add_missing_loci_chk)
     val_keep_na <- svalue(f1_keep_na_chk)
     val_ignore_case <- svalue(f1_ignore_case_chk)
     val_name <- svalue(f2_save_edt)
-    
-    if(!is.null(.gData) & !is.null(.gRef)){
+    val_filter <- svalue(f1_filter_opt, index=TRUE)
+    val_kit <- svalue(g0_kit_drp)
+    val_exclude <- svalue(g0_kit_chk)
+
+    # Check if filter by kit bins.
+    if(val_filter == 2){
+      
+      # Get markers, bins and flag for virtual bins.
+      val_ref <- getKit(kit=val_kit, what="VIRTUAL")
+      
+      if(val_exclude){
+        # Remove virtual bins.
+        val_ref <- val_ref[val_ref$Virtual == 0, ]
+      }
+      
+    }
+      
+    if(!is.null(val_data) & !is.null(val_ref)){
       
       # Change button.
       svalue(filter_btn) <- "Processing..."
       enabled(filter_btn) <- FALSE
   
-      datanew <- filterProfile(data=.gData,
-                               ref=.gRef,
+      datanew <- filterProfile(data=val_data,
+                               ref=val_ref,
                                addMissingLoci=val_add_missing_loci,
                                keepNA=val_keep_na,
                                ignoreCase=val_ignore_case)
@@ -275,7 +369,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       saveObject(name=val_name, object=datanew, parent=w, env=env)
       
       if(debug){
-        print(datanew)
+        print(str(datanew))
         print(paste("EXIT:", match.call()[[1]]))
       }
       
@@ -296,6 +390,34 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
 
   # INTERNAL FUNCTIONS ########################################################
   
+  .refreshOptions <- function(){
+
+    val_opt <- svalue(f1_filter_opt, index=TRUE)
+    
+    if(val_opt == 1){
+      
+      enabled(g0_refset_lbl) <- TRUE
+      enabled(g0_refset_drp) <- TRUE
+      enabled(g0_check_btn) <- TRUE
+      
+      enabled(g0_kit_lbl) <- FALSE
+      enabled(g0_kit_drp) <- FALSE
+      enabled(g0_kit_chk) <- FALSE
+      
+    } else if(val_opt == 2){
+      
+      enabled(g0_refset_lbl) <- FALSE
+      enabled(g0_refset_drp) <- FALSE
+      enabled(g0_check_btn) <- FALSE
+      
+      enabled(g0_kit_lbl) <- TRUE
+      enabled(g0_kit_drp) <- TRUE
+      enabled(g0_kit_chk) <- TRUE
+      
+    }
+    
+  }
+  
   .loadSavedSettings <- function(){
     
     # First check status of save flag.
@@ -307,8 +429,8 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       }  
     } else {
       # Load save flag.
-      if(exists(".filterProfile_gui_savegui", envir=env, inherits = FALSE)){
-        svalue(f1_savegui_chk) <- get(".filterProfile_gui_savegui", envir=env)
+      if(exists(".strvalidator_filterProfile_gui_savegui", envir=env, inherits = FALSE)){
+        svalue(f1_savegui_chk) <- get(".strvalidator_filterProfile_gui_savegui", envir=env)
       }
       if(debug){
         print("Save GUI status loaded!")
@@ -320,14 +442,17 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     
     # Then load settings if true.
     if(svalue(f1_savegui_chk)){
-      if(exists(".filterProfile_gui_add_loci", envir=env, inherits = FALSE)){
-        svalue(f1_add_missing_loci_chk) <- get(".filterProfile_gui_add_loci", envir=env)
+      if(exists(".strvalidator_filterProfile_gui_add_loci", envir=env, inherits = FALSE)){
+        svalue(f1_add_missing_loci_chk) <- get(".strvalidator_filterProfile_gui_add_loci", envir=env)
       }
-      if(exists(".filterProfile_gui_keep_na", envir=env, inherits = FALSE)){
-        svalue(f1_keep_na_chk) <- get(".filterProfile_gui_keep_na", envir=env)
+      if(exists(".strvalidator_filterProfile_gui_keep_na", envir=env, inherits = FALSE)){
+        svalue(f1_keep_na_chk) <- get(".strvalidator_filterProfile_gui_keep_na", envir=env)
       }
-      if(exists(".filterProfile_gui_ignore_case", envir=env, inherits = FALSE)){
-        svalue(f1_ignore_case_chk) <- get(".filterProfile_gui_ignore_case", envir=env)
+      if(exists(".strvalidator_filterProfile_gui_ignore_case", envir=env, inherits = FALSE)){
+        svalue(f1_ignore_case_chk) <- get(".strvalidator_filterProfile_gui_ignore_case", envir=env)
+      }
+      if(exists(".strvalidator_filterProfile_gui_by", envir=env, inherits = FALSE)){
+        svalue(f1_filter_opt) <- get(".strvalidator_filterProfile_gui_by", envir=env)
       }
       if(debug){
         print("Saved settings loaded!")
@@ -341,24 +466,28 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
     # Then save settings if true.
     if(svalue(f1_savegui_chk)){
       
-      assign(x=".filterProfile_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
-      assign(x=".filterProfile_gui_add_loci", value=svalue(f1_add_missing_loci_chk), envir=env)
-      assign(x=".filterProfile_gui_keep_na", value=svalue(f1_keep_na_chk), envir=env)
-      assign(x=".filterProfile_gui_ignore_case", value=svalue(f1_ignore_case_chk), envir=env)
+      assign(x=".strvalidator_filterProfile_gui_savegui", value=svalue(f1_savegui_chk), envir=env)
+      assign(x=".strvalidator_filterProfile_gui_add_loci", value=svalue(f1_add_missing_loci_chk), envir=env)
+      assign(x=".strvalidator_filterProfile_gui_keep_na", value=svalue(f1_keep_na_chk), envir=env)
+      assign(x=".strvalidator_filterProfile_gui_ignore_case", value=svalue(f1_ignore_case_chk), envir=env)
+      assign(x=".strvalidator_filterProfile_gui_by", value=svalue(f1_filter_opt), envir=env)
       
     } else { # or remove all saved values if false.
       
-      if(exists(".filterProfile_gui_savegui", envir=env, inherits = FALSE)){
-        remove(".filterProfile_gui_savegui", envir = env)
+      if(exists(".strvalidator_filterProfile_gui_savegui", envir=env, inherits = FALSE)){
+        remove(".strvalidator_filterProfile_gui_savegui", envir = env)
       }
-      if(exists(".filterProfile_gui_add_loci", envir=env, inherits = FALSE)){
-        remove(".filterProfile_gui_add_loci", envir = env)
+      if(exists(".strvalidator_filterProfile_gui_add_loci", envir=env, inherits = FALSE)){
+        remove(".strvalidator_filterProfile_gui_add_loci", envir = env)
       }
-      if(exists(".filterProfile_gui_keep_na", envir=env, inherits = FALSE)){
-        remove(".filterProfile_gui_keep_na", envir = env)
+      if(exists(".strvalidator_filterProfile_gui_keep_na", envir=env, inherits = FALSE)){
+        remove(".strvalidator_filterProfile_gui_keep_na", envir = env)
       }
-      if(exists(".filterProfile_gui_ignore_case", envir=env, inherits = FALSE)){
-        remove(".filterProfile_gui_ignore_case", envir = env)
+      if(exists(".strvalidator_filterProfile_gui_ignore_case", envir=env, inherits = FALSE)){
+        remove(".strvalidator_filterProfile_gui_ignore_case", envir = env)
+      }
+      if(exists(".strvalidator_filterProfile_gui_by", envir=env, inherits = FALSE)){
+        remove(".strvalidator_filterProfile_gui_by", envir = env)
       }
       
       if(debug){
@@ -376,6 +505,7 @@ filterProfile_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Load GUI settings.
   .loadSavedSettings()
+  .refreshOptions()
   
   # Show GUI.
   visible(w) <- TRUE
